    maybes:
    	[ ] linter:
    		[ ] https://docs.astral.sh/ruff/
    		[ ] https://pypi.org/project/ruff/
    		[ ] https://black.readthedocs.io/en/stable/

    	[ ] static typing:
    		[ ] mypy

    	https://github.com/PyCQA/flake8

    	[ ] non_venomous build example

    			build an example that shows
    			how to setup status checks.

    			/module
    				/_status
    					status_1.py
    					status_2.py
    					status_3.py

    				statu.proc.py

    	[ ] CWD option:

    			cwd of each process = directory that the status file is in...